Learn R Programming

cyclotomic (version 1.3.0)

as.cyclotomic: Coercion to a 'cyclotomic' object

Description

Coercion to a 'cyclotomic' object

Usage

# S4 method for character
as.cyclotomic(x)

# S4 method for cyclotomic as.cyclotomic(x)

# S4 method for numeric as.cyclotomic(x)

# S4 method for bigz as.cyclotomic(x)

# S4 method for bigq as.cyclotomic(x)

Value

A cyclotomic object.

Arguments

x

a cyclotomic object or an object yielding a quoted integer or a quoted fraction after an application of as.character

Examples

Run this code
as.cyclotomic(2)
as.cyclotomic("1/3")

Run the code above in your browser using DataLab