powered by
Coercion to a 'cyclotomic' object
# S4 method for character as.cyclotomic(x)# S4 method for cyclotomic as.cyclotomic(x)# S4 method for numeric as.cyclotomic(x)# S4 method for bigz as.cyclotomic(x)# S4 method for bigq as.cyclotomic(x)
# S4 method for cyclotomic as.cyclotomic(x)
# S4 method for numeric as.cyclotomic(x)
# S4 method for bigz as.cyclotomic(x)
# S4 method for bigq as.cyclotomic(x)
A cyclotomic object.
cyclotomic
a cyclotomic object or an object yielding a quoted integer or a quoted fraction after an application of as.character
as.character
as.cyclotomic(2) as.cyclotomic("1/3")
Run the code above in your browser using DataLab