powered by
Square root of an integer or a rational number as a cyclotomic number. This is slow.
cycSqrt(x)
The square root of x as a cyclotomic number.
x
an integer, a gmp rational number (bigq object), or a fraction given as a string (e.g. "5/3")
bigq
"5/3"
cycSqrt(2) phi <- (1 + cycSqrt(5)) / 2 # the golden ratio phi^2 - phi # should be 1
Run the code above in your browser using DataLab